==> apache-kie-10.0.0-incubating-sources.zip: incubator-kie-tools/packages/sonataflow-deployment-webapp/src/navigation/RuntimeToolsRoutesSwitch.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import React from "react";
import { Route, Switch } from "react-router-dom";
import { RuntimeToolsWorkflowInstances } from "../runtimeTools/pages/RuntimeToolsWorkflowInstances";
import { routes } from "../routes";
import { RuntimeToolsWorkflowDetails } from "../runtimeTools/pages/RuntimeToolsWorkflowDetails";

export function RuntimeToolsRoutesSwitch() {
  return (
    <Switch>
      <Route path={routes.runtimeTools.workflowInstances.path({})}>
        <RuntimeToolsWorkflowInstances />
      </Route>
      <Route path={routes.runtimeTools.workflowDetails.path({ workflowId: ":workflowId" })}>
        {({ match }) => <RuntimeToolsWorkflowDetails workflowId={match!.params.workflowId!} />}
      </Route>
    </Switch>
  );
}

==> apache-kie-10.1.0-incubating-sources.zip: incubator-kie-tools/packages/sonataflow-deployment-webapp/src/navigation/RuntimeToolsRoutesSwitch.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import React from "react";
import { Route, Switch } from "react-router-dom";
import { RuntimeToolsWorkflowInstances } from "../runtimeTools/pages/RuntimeToolsWorkflowInstances";
import { routes } from "../routes";
import { RuntimeToolsWorkflowDetails } from "../runtimeTools/pages/RuntimeToolsWorkflowDetails";
import { RuntimeToolsWorkflowDefinitions } from "../runtimeTools/pages/RuntimeToolsWorkflowDefinitions";

export function RuntimeToolsRoutesSwitch() {
  return (
    <Switch>
      <Route path={routes.runtimeTools.workflowDefinitions.path({})}>
        <RuntimeToolsWorkflowDefinitions />
      </Route>
      <Route path={routes.runtimeTools.workflowInstances.path({})}>
        <RuntimeToolsWorkflowInstances />
      </Route>
      <Route path={routes.runtimeTools.workflowDetails.path({ workflowId: ":workflowId" })}>
        {({ match }) => <RuntimeToolsWorkflowDetails workflowId={match!.params.workflowId!} />}
      </Route>
    </Switch>
  );
}
